@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.3
-id: yesod-1.4.3-1925bfb515c4eef758a4f01d12bb78cc
-key: yesod_DUh5S79ECK8FVzeddnH0St
+id: yesod-1.4.3-89d663579be8afc78aa2c036ac16a3d8
+key: yesod_L58tBxbDKEVEF9cONihwwl
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,37 +21,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
-hs-libraries: HSyesod-1.4.3-DUh5S79ECK8FVzeddnH0St
+hs-libraries: HSyesod-1.4.3-L58tBxbDKEVEF9cONihwwl
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.1.4-86f3cf1b57353fec7f96aad67f54b36b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
+    fast-logger-2.4.6-262e16722c1e4a82f3b9c171b34b1422
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
+    monad-logger-0.3.18-8d0d3ee0b0c9e28288fbc3f8ad4970cb
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
-    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    shakespeare-2.0.8.2-9d634aa5cbfd84967239f7d2ea21fe42
+    streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    wai-extra-3.0.15-e42802427c6ef24de665b6ca33fb34be
-    wai-logger-2.2.4.1-b4d6891e20083c91ee31e279044b2010
-    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
-    yaml-0.8.17-256008eb42bc8c59588e1e26ecb14272
-    yesod-auth-1.4.13.1-02ce33af0017c100af6587c6e90a960e
-    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
-    yesod-form-1.4.7-6556fa2dbba4c60b35adfc5077eb6d41
-    yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    wai-extra-3.0.15.1-805c88586e75ad2629c1f825e3e3174b
+    wai-logger-2.2.7-ce523aca7009dcd9edbddd06c7250c99
+    warp-3.2.6-88951d0d70fd1890006e06da62bd7b17
+    yaml-0.8.17.1-0d2269c3661604071b13bd3e036107ab
+    yesod-auth-1.4.13.2-8b814b29f0db7fe2c6087994080e0e8c
+    yesod-core-1.4.20.2-0deed42ce8646909d9e6f7d8cb856025
+    yesod-form-1.4.7.1-6b4f60eedefa751296dea3285755c587
+    yesod-persistent-1.4.0.5-f9c4aef4e19cb23b8351ed6db2610b12
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
